@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-**$Author: antanas $
-**$Date: 2019-11-15 20:06:25 +0200 (Fri, 15 Nov 2019) $ 
-**$Revision: 7424 $
-**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/components/codcif/cif.c $
+**$Author: andrius $
+**$Date: 2021-05-26 08:15:47 +0300 (Wed, 26 May 2021) $ 
+**$Revision: 8796 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/components/codcif/cif.c $
 \*---------------------------------------------------------------------------*/
 
 /* representation of the CIF data for the CIF parser. */
@@ -20,7 +20,6 @@
 #include <allocx.h>
 #include <assert.h>
 #include <cexceptions.h>
-#include <cxprintf.h>
 #include <stringx.h>
 #include <yy.h>
 
