@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-**$Author: antanas $
-**$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $ 
-**$Revision: 8230 $
-**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/components/codcif/common.c $
+**$Author: andrius $
+**$Date: 2021-05-25 13:10:16 +0300 (Tue, 25 May 2021) $ 
+**$Revision: 8793 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/components/codcif/common.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -15,7 +15,6 @@
 #include <unistd.h>
 #include <string.h>
 #include <allocx.h>
-#include <cxprintf.h>
 #include <cif_grammar_flex.h>
 #include <cif_lex_buffer.h>
 
@@ -296,8 +295,9 @@ char *clean_string( char *src, int is_textfield, CIF_COMPILER *cif_cc, cexceptio
                     *dest = '\0';
                     length += DELTA;
                     new = reallocx( new, length + 1, &inner );
-                    strcat( new, cxprintf( "&#x%04X;", *src & 255 ) );
-                    dest = new + strlen( new ) - 1;
+                    dest = new + strlen( new );
+                    sprintf( dest, "&#x%04X;\\0", *src & 255 );
+                    dest += DELTA - 1;
                     if( non_ascii_explained == 0 ) {
                         if( is_textfield == 0 ) {
                             print_message( cif_cc, "WARNING", "non-ASCII symbols "
