@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-**$Author: antanas $
-**$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $ 
-**$Revision: 8230 $
-**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/components/codcif/datablock.c $
+**$Author: andrius $
+**$Date: 2021-05-26 08:15:47 +0300 (Wed, 26 May 2021) $ 
+**$Revision: 8796 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/components/codcif/datablock.c $
 \*---------------------------------------------------------------------------*/
 
 /* representation of the CIF data for the CIF parser. */
@@ -18,7 +18,6 @@
 #include <allocx.h>
 #include <assert.h>
 #include <cexceptions.h>
-#include <cxprintf.h>
 #include <stringx.h>
 
 void *datablock_subsystem = &datablock_subsystem;
