@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-**$Author: antanas $
-**$Date: 2020-01-23 09:06:12 +0200 (Thu, 23 Jan 2020) $ 
-**$Revision: 7671 $
-**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/components/codcif/programs/cifvalues.c $
+**$Author: andrius $
+**$Date: 2021-05-26 08:15:47 +0300 (Wed, 26 May 2021) $ 
+**$Revision: 8796 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/components/codcif/programs/cifvalues.c $
 \*---------------------------------------------------------------------------*/
 
 /* uses: */
@@ -16,10 +16,9 @@
 #include <cif_grammar_y.h>
 #include <cif_grammar_flex.h>
 #include <allocx.h>
-#include <cxprintf.h>
 #include <version.h>
 
-static char *source_URL = "$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/components/codcif/programs/cifvalues.c $";
+static char *source_URL = "$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/components/codcif/programs/cifvalues.c $";
 
 static char *usage_text[2] = {
 
