@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-** $Author: saulius $
-** $Date: 2011-03-08 20:45:40 +0200 (Tue, 08 Mar 2011) $ 
-** $Revision: 1590 $
-** $URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/externals/cexceptions/cxprintf.c $
+** $Author: andrius $
+** $Date: 2021-05-25 08:29:29 +0300 (Tue, 25 May 2021) $ 
+** $Revision: 8790 $
+** $URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/externals/cexceptions/cxprintf.c $
 \*---------------------------------------------------------------------------*/
 
 /* composing error message for the exception handling subsystem */
@@ -14,6 +14,16 @@
 #include <stdarg.h>
 #include <stdio.h>
 
+#ifndef CXPRINTF_BUFFER_SIZE
+#define CXPRINTF_BUFFER_SIZE 1024
+#endif
+
+#ifndef HAS_VSNPRINTF
+#if _XOPEN_SOURCE >= 500 || _ISOC99_SOURCE || _BSD_SOURCE
+#define HAS_VSNPRINTF 1
+#endif
+#endif
+
 const char* cxprintf( const char * format, ... )
 {
     const char *message;
@@ -27,11 +37,13 @@ const char* cxprintf( const char * format, ... )
 
 const char* vcxprintf( const char * format, va_list args )
 {
-    static char error_message[200] = "";
+    static char error_message[CXPRINTF_BUFFER_SIZE] = "";
 
-    /*
+#if HAS_VSNPRINTF
     vsnprintf( error_message, sizeof(error_message), format, args );
-    */
+#else
+#warning Can not safely compile 'vcxprintf' on this system without buffer overruns – no 'vsnprintf' provided by libc
     vsprintf( error_message, format, args );
+#endif
     return error_message;
 }
