@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2020-08-26 17:51:21 +0300 (Wed, 26 Aug 2020) $ 
-#$Revision: 8429 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/AtomNeighbours.pm $
+#$Author: antanas $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/AtomNeighbours.pm $
 #------------------------------------------------------------------------------
 #*
 #  Build a list of neighbours for each atom from an atom list.
@@ -293,8 +293,6 @@ sub make_neighbour_list_slow($$$$$)
 #==============================================================================
 # Generates neighbour list from Chemistry::Mol object. Tested with the
 # version 0.37 of the aforementioned module.
-#
-# Deprecated as Chemistry::Mol fails on newer Perl versions.
 sub neighbour_list_from_chemistry_mol
 {
     my( $mol ) = @_;
@@ -324,6 +322,7 @@ sub neighbour_list_from_chemistry_mol
         $atom_info{"unity_matrix_applied"}  = 1;
         $atom_info{"translation_id"}        = "555";
         $atom_info{"translation"}           = [ 0, 0, 0 ];
+        $atom_info{"coordinates_ortho"}     = [ $atom->coords->array() ];
 
         $atom_info{"chemical_type"}         = $atom->symbol();
         $atom_info{"assembly"}              = ".";
