@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2020-08-24 17:30:51 +0300 (Mon, 24 Aug 2020) $ 
-#$Revision: 8413 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/AuthorNames.pm $
+#$Author: antanas $
+#$Date: 2021-05-07 16:51:01 +0300 (Fri, 07 May 2021) $
+#$Revision: 8775 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/AuthorNames.pm $
 #------------------------------------------------------------------------------
 #*
 #* Subroutines for parsing and regularisation of author names.
@@ -118,8 +118,8 @@ sub parse_author_name
 
     if( %$space ) {
         warn "WARNING, name '$unparsed_name' contains " .
-             join( ' and ', sort keys %$space ) . ' spaces, ' .
-             'that is not permitted in names' . "\n";
+             join( ' and ', sort keys %$space ) . ' spaces ' .
+             'that are not permitted in names' . "\n";
     }
 
     if( $UCS_author =~ /^([^[:alpha:]])/ ||
@@ -230,7 +230,7 @@ sub parse_author_name
             $parsed_name{'jr'} = [ split( ' ', $parsed_name{'jr'} ) ];
         }
         if( defined $parsed_name{'initials'} ) {
-            $parsed_name{'initials'} = 
+            $parsed_name{'initials'} =
                 [
                  # S.G. 2016-10-04:
                  # Use simultaneously a look-ahead and look-behind
