@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-05-06 11:45:55 +0300 (Wed, 06 May 2020) $
-#$Revision: 7921 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/DDL/DDL1.pm $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/DDL/DDL1.pm $
 #------------------------------------------------------------------------------
 #*
 #* Handles CIF dictionary files written in Dictionary Definition Language (DDL1).
@@ -206,7 +206,7 @@ sub canonicalise_value
 
     if ( $data_type eq 'numb' )  {
         my ( $uvalue, $su ) = unpack_cif_number($value);
-        if ( looks_like_number( $uvalue ) ) {
+        if ( looks_like_number( $uvalue ) && $uvalue !~ m/^[+-]?(inf|nan)/i ) {
             return pack_precision( $uvalue + 0, $su );
         } else {
             return $value;
@@ -224,7 +224,7 @@ sub canonicalise_value
 #
 # @param $dic
 #       Reference to a DDL1 dictionary structure as returned by
-#       the COD::CIF::Parser. 
+#       the COD::CIF::Parser.
 # @return
 #       Reference to a hash of the following form:
 #       {
@@ -364,14 +364,14 @@ sub is_proper_category_name
 
 ##
 # Converts a category name from the form that is used in category definitions
-# to the form that is used in data item definitions. 
+# to the form that is used in data item definitions.
 #
 # Category names in category definitions are recorded using the '_name'
 # data item and take the form of '_category_name_[]'. These names are
 # also called 'pseudo' data names.
 #
 # Category names in data item definitions are recorded using the '_category'
-# data item and take the form of 'category_name'. 
+# data item and take the form of 'category_name'.
 #
 # @source [1]
 #       3.1.5.3. Category descriptions,
