@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-10 15:53:55 +0300 (Fri, 10 Jul 2020) $
-#$Revision: 8185 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.0.1/src/lib/perl5/COD/CIF/DDL/DDLm.pm $
+#$Date: 2020-10-19 22:49:34 +0300 (Mon, 19 Oct 2020) $
+#$Revision: 8554 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/DDL/DDLm.pm $
 #------------------------------------------------------------------------------
 #*
 #* A set of subroutines used for handling the CIF
@@ -24,11 +24,13 @@ our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
     build_ddlm_dic
     canonicalise_ddlm_value
+    get_all_data_names
     get_category_id
     get_data_alias
     get_data_name
     get_definition_class
     get_definition_scope
+    get_dictionary_class
     get_type_contents
     get_type_container
     get_type_dimension
@@ -41,6 +43,7 @@ our @EXPORT_OK = qw(
 my %data_item_defaults = (
     '_definition.scope' => 'Item',
     '_definition.class' => 'Datum',
+    '_dictionary.class' => 'Instance',
     '_type.container'   => 'Single',
     '_type.contents'    => 'Text',
     '_type.purpose'     => 'Describe',
@@ -170,6 +173,13 @@ sub get_definition_scope
     return get_dic_item_value( $data_frame, '_definition.scope' );
 }
 
+sub get_dictionary_class
+{
+    my ( $data_frame ) = @_;
+
+    return get_dic_item_value( $data_frame, '_dictionary.class' );
+}
+
 sub get_dic_item_value
 {
     my ( $data_frame, $data_name ) = @_;
@@ -185,6 +195,7 @@ sub get_dic_item_value
 ##
 # Builds a data structure that is more convenient to traverse in regards to
 # the Dictionary, Category and Item context classification.
+#
 # @param $data
 #       CIF data block as returned by the COD::CIF::Parser.
 # @return $struct
@@ -212,14 +223,25 @@ sub build_ddlm_dic
 
         if ( $scope eq 'Dictionary' ) {
             next; # TODO: do more research on this scope
-        } elsif ( $scope eq 'Category' ) {
-            $categories{ lc get_data_name( $save_block ) } = $save_block;
+        }
+
+        my $data_name = get_data_name( $save_block );
+        if (!defined $data_name) {
+            warn "WARNING, the '$save_block->{'name'}' save block does not " .
+                 'contain the mandatory \'_definition.id\' data item -- ' .
+                 'the save block will be ignored in further processing' . "\n";
+            next;
+        }
+        $data_name = lc $data_name;
+
+        if ( $scope eq 'Category' ) {
+            $categories{ $data_name } = $save_block;
         } elsif ( $scope eq 'Item' ) {
-            $items{ lc get_data_name( $save_block ) } = $save_block;
+            $items{ $data_name } = $save_block;
         } else {
             warn "WARNING, the '$save_block->{'name'}' save block contains " .
-                 "an unrecognised '$scope' definition scope" .
-                 ' -- the save block will be ignored in further processing' . "\n"
+                 "an unrecognised '$scope' definition scope -- " .
+                 'the save block will be ignored in further processing' . "\n"
         }
     };
 
@@ -265,6 +287,30 @@ sub get_data_name
     return $data_name;
 }
 
+##
+# Extracts all provided data item names from a data item definition frame.
+# The data names include the main definition id and definition id aliases.
+#
+# @param $data_frame
+#       Data item definition frame as returned by the COD::CIF::Parser.
+# @return $data_name
+#       Array reference to a list of data names identifying a data item
+#       or a reference to an empty array if no names were found.
+##
+sub get_all_data_names
+{
+    my ( $data_frame ) = @_;
+
+    my @data_names;
+    my $data_name = get_data_name($data_frame);
+    if (defined $data_name) {
+        push @data_names, $data_name;
+    }
+    push @data_names, @{get_data_alias($data_frame)};
+
+    return \@data_names;
+}
+
 ##
 # Extracts the category id from the data item definition frame.
 # In case the definition frame does not contain a category id
@@ -398,7 +444,7 @@ sub canonicalise_ddlm_value
          $content_type eq 'real'
     ) {
         my ( $uvalue, $su ) = unpack_cif_number($value);
-        if ( looks_like_number( $uvalue ) ) {
+        if ( looks_like_number( $uvalue ) && $uvalue !~ m/^[+-]?(inf|nan)/i ) {
             return pack_precision( $uvalue + 0, $su );
         } else {
             return $value;
