@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-08-13 18:14:41 +0300 (Thu, 13 Aug 2020) $
-#$Revision: 8309 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
+#$Date: 2020-10-19 22:49:34 +0300 (Mon, 19 Oct 2020) $
+#$Revision: 8554 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
 #------------------------------------------------------------------------------
 #*
 #* A set of subroutines for handling ranges as defined in the Dictionary
@@ -225,7 +225,7 @@ sub is_in_range_numeric
     my $sigma = $param->{'sigma'};
     my $multiplier = $param->{'multiplier'};
 
-    if( ! looks_like_number($value) ) {
+    if( !looks_like_number($value) || $value =~ m/^[+-]?(inf|nan)/i ) {
         return 0;
     }
 
