@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-05 15:52:27 +0200 (Tue, 05 Nov 2019) $ 
-#$Revision: 7303 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/Data.pm $
+#$Date: 2021-04-29 11:28:43 +0300 (Thu, 29 Apr 2021) $
+#$Revision: 8751 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Data.pm $
 #------------------------------------------------------------------------------
 #*
 #  Common subroutines for extracting data/creating data structures from
@@ -29,6 +29,7 @@ our @EXPORT_OK = qw(
     get_content_encodings
     get_source_data_block_name
     get_symmetry_operators
+    calculate_shelx_checksum
     space_group_data_names
 );
 
@@ -447,7 +448,7 @@ sub lookup_space_group
 }
 
 # Returns data block name. Original source data block name, if specified, is
-# prefered. If not specified, current data block name is returned.
+# preferred. If not specified, current data block name is returned.
 sub get_source_data_block_name
 {
     my( $datablock, $options ) = @_;
@@ -474,7 +475,7 @@ sub get_formula_units_z
     my $warnings = check_formula_units_z( $data_block );
 
     # TODO: currently floating-point values like "4.00" are treated as
-    # errouneous, but they should probably be converted to integers with
+    # erroneous, but they should probably be converted to integers with
     # a warning
     if ( @{$warnings} ) {
         foreach ( @$warnings ) { warn $_ . "\n"; };
@@ -522,4 +523,22 @@ sub get_tag_variants
     return map { $_ ne lc $_ ? ( $_, lc $_ ) : ( $_ ) } @tags;
 }
 
+# Implemented as in FinalCif (https://github.com/dkratzert/FinalCif/blob/608217753a04fe314cd44673c1b70bf4e30b9e7d/cif/cif_file_io.py#L386)
+# According to https://github.com/dkratzert/FinalCif/issues/3, the
+# algorithm has been posted on the Bruker-users mailing list by
+# Berthold Stöger.
+sub calculate_shelx_checksum
+{
+    my( $content ) = @_;
+
+    my $sum = 0;
+    for (split //, $content) {
+        next if ord $_ <= 32;
+        $sum += ord $_;
+        $sum = $sum % 714025 if $sum >= 714025;
+    }
+
+    return (($sum % 714025) * 1366 + 150889) % 714025 % 100000;
+}
+
 1;
