@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $
-#$Revision: 8230 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.0.1/src/lib/perl5/COD/CIF/Data/CIF2COD.pm $
+#$Date: 2021-04-29 11:28:43 +0300 (Thu, 29 Apr 2021) $
+#$Revision: 8751 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Data/CIF2COD.pm $
 #------------------------------------------------------------------------------
 #*
 #  Parse a CIF file, prepare a COD database table entry from it.
@@ -131,7 +131,7 @@ my %text_value_fields2tags = (
    'radType'        => [ qw( _diffrn_radiation_type ) ],
    'radSymbol'      => [ qw( _diffrn_radiation_xray_symbol ) ],
    'duplicateof'    => [ qw( _cod_related_duplicate_entry.code
-                             _cod_related_duplicate_entry_code 
+                             _cod_related_duplicate_entry_code
                              _cod_duplicate_entry
                              _[local]_cod_duplicate_entry ) ],
    'optimal'        => [ qw( _cod_related_optimal_entry.code
@@ -227,7 +227,7 @@ my %space_groups = map {
 #       # Boolean value. Default '0'.
 #       # Include the implicit hydrogen atoms into the summary chemical formula.
 #       # The implicit hydrogen atoms are specified using
-#       # the _atom_site_attached_hydrogens data item. 
+#       # the _atom_site_attached_hydrogens data item.
 #           'use_attached_hydrogens' => 1,
 #       # Boolean value. Default '1'.
 #       # Accept data blocks without fractional coordinates.
@@ -484,14 +484,14 @@ sub calculate_formula_sum
     }
 
     # FIXME: the local formula mitigations were a quick fix, however,
-    # it would be worthwhile to investingate and correct the issue
+    # it would be worthwhile to investigate and correct the issue
     # in the formula generation subroutine
     if ( defined $formula ) {
-        # Mitigate formula generated by unknown ('?') atomic coordinates 
+        # Mitigate formula generated by unknown ('?') atomic coordinates
         if ( $formula =~ m/^[?][0-9.]*$/ ) {
             return undef;
         }
-        # Mitigate formula generated by inapplicable ('.') atomic coordinates 
+        # Mitigate formula generated by inapplicable ('.') atomic coordinates
         if ( $formula eq '' ) {
             return undef;
         }
@@ -683,14 +683,14 @@ sub get_cod_status_from_error_flag
 #           'formula'    => 'H2 O'
 #           # Summary chemical formula calculated from the atomic coordinates
 #           'calcformula'=> 'H2 O'
-#       } 
+#       }
 # @return
 #       Number of distinct chemical elements.
 ##
 sub get_number_of_elements
 {
     my ( $formulae_values ) = @_;
-    
+
     my $formula;
     if ( $formulae_values->{'formula'} ne '?'  ) {
         $formula = $formulae_values->{'formula'};
@@ -698,7 +698,7 @@ sub get_number_of_elements
         $formula = $formulae_values->{'calcformula'};
     }
 
-    my $number_of_elements = 0;    
+    my $number_of_elements = 0;
     if ( defined $formula ) {
         $number_of_elements = count_number_of_elements( $formula )
     }
@@ -948,7 +948,8 @@ sub validate_SQL_types
         next if !exists $types->{$key};
 
         if( $types->{$key} =~ /^(float|double|(small|medium)int)/i &&
-            !looks_like_number( $data->{$key} ) ) {
+            !(looks_like_number( $data->{$key} ) &&
+              $data->{$key} !~ /^[+-]?(inf|nan)/i) ) {
             warn "value of '$key' ('$data->{$key}') does not seem " .
                  'to be numeric -- value will be treated as undefined' . "\n";
             $data->{$key} = undef;
