@@ -1,8 +1,8 @@
 #--*-perl-*-------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2020-07-07 11:45:07 +0300 (Tue, 07 Jul 2020) $
-#$Revision: 8109 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/Data/CODFlags.pm $
+#$Date: 2020-12-18 08:05:08 +0200 (Fri, 18 Dec 2020) $
+#$Revision: 8635 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Data/CODFlags.pm $
 #-----------------------------------------------------------------------
 # Test dataset on various criteria.
 #-----------------------------------------------------------------------
@@ -16,6 +16,8 @@ use COD::CIF::Tags::Manage qw(
     has_special_value
     tag_is_empty
 );
+use COD::Precision qw( unpack_cif_number );
+use List::MoreUtils qw( any );
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -26,6 +28,7 @@ our @EXPORT_OK = qw(
     is_disordered
     is_suboptimal
     is_theoretical
+    has_attached_hydrogens
     has_coordinates
     has_hkl
     has_partially_occupied_ordered_atoms
@@ -213,6 +216,22 @@ sub is_theoretical($)
     return 0;
 }
 
+sub has_attached_hydrogens($)
+{
+    my ($data_block) = @_;
+
+    if( !contains_data_item( $data_block, '_atom_site_attached_hydrogens' ) ) {
+        return 0;
+    }
+
+    return 1 if any { !has_special_value( $data_block,
+                                          '_atom_site_attached_hydrogens',
+                                          $_ ) &&
+                      $data_block->{values}{'_atom_site_attached_hydrogens'}[$_] ne '0' }
+                    0..$#{$data_block->{values}{'_atom_site_attached_hydrogens'}};
+    return 0;
+}
+
 sub has_coordinates($)
 {
     my ($data_block) = @_;
@@ -268,7 +287,7 @@ sub has_partially_occupied_ordered_atoms($)
     for my $i (0..$#{$data_block->{'values'}{'_atom_site_label'}}) {
         next if has_special_value($data_block, '_atom_site_occupancy', $i);
         next if has_special_value($data_block, '_atom_site_disorder_group', $i);
-        next if $values->{'_atom_site_occupancy'}[$i] == 1;
+        next if unpack_cif_number( $values->{'_atom_site_occupancy'}[$i] ) >= 1;
         return 1;
     }
 
