@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-03-10 16:36:52 +0200 (Tue, 10 Mar 2020) $
-#$Revision: 7772 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.0.1/src/lib/perl5/COD/CIF/Data/Check.pm $
+#$Date: 2021-05-10 17:42:02 +0300 (Mon, 10 May 2021) $
+#$Revision: 8781 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Data/Check.pm $
 #------------------------------------------------------------------------------
 #*
 #* Perform various checks of the CIF data.
@@ -16,7 +16,10 @@ use Digest::MD5 qw( md5_hex );
 use Digest::SHA qw( sha1_hex );
 use COD::AuthorNames qw( parse_author_name );
 use COD::Escape qw( decode_textfield );
-use COD::CIF::Data qw( get_content_encodings );
+use COD::CIF::Data qw(
+    get_content_encodings
+    calculate_shelx_checksum
+);
 use COD::CIF::Data::CODFlags qw(
     has_hkl
     has_powder_diffraction_intensities
@@ -33,6 +36,7 @@ use COD::DateTime qw( parse_datetime );
 require Exporter;
 our @ISA = qw( Exporter );
 our @EXPORT_OK = qw(
+check_adp_presence
 check_author_names
 check_bibliography
 check_chemical_formula_sum
@@ -42,6 +46,7 @@ check_formula_sum_syntax
 check_limits
 check_mandatory_presence
 check_pdcif_relations
+check_shelx_checksums
 check_simultaneous_presence
 check_su_eligibility
 check_temperature_factors
@@ -267,6 +272,7 @@ sub check_embedded_file_integrity
             }
         }
     }
+
     return \@messages;
 }
 
@@ -349,7 +355,7 @@ sub check_occupancies
     my $values = $dataset->{'values'};
     if ( exists $values->{'_atom_site_occupancy'} ) {
         for (my $i = 0; $i < @{$values->{'_atom_site_label'}}; $i++) {
-            if ( ( $values->{'_atom_site_occupancy'}[$i] eq '.' || 
+            if ( ( $values->{'_atom_site_occupancy'}[$i] eq '.' ||
                    $values->{'_atom_site_occupancy'}[$i] eq '?' ) &&
                  ( !exists $values->{'_atom_site_calc_flag'} ||
                    $values->{'_atom_site_calc_flag'}[$i] ne 'dum' ) ) {
@@ -366,6 +372,47 @@ sub check_occupancies
     return \@messages;
 }
 
+sub check_shelx_checksums
+{
+    my ($dataset) = @_;
+    my @messages;
+    my $values = $dataset->{values};
+
+    for my $type ('fab', 'hkl', 'res') {
+        next if !contains_data_item( $dataset, "_shelx_${type}_checksum" );
+        next if tag_is_empty(        $dataset, "_shelx_${type}_checksum" );
+        next if tag_is_unknown(      $dataset, "_shelx_${type}_checksum" );
+
+        if( !contains_data_item( $dataset, "_shelx_${type}_file" ) ) {
+            push @messages, "NOTE, data item '_shelx_${type}_checksum' " .
+                            "is present, but '_shelx_${type}_file' data " .
+                            'item is missing';
+            next;
+        }
+        next if tag_is_empty(    $dataset, "_shelx_${type}_file" );
+        next if tag_is_unknown(  $dataset, "_shelx_${type}_file" );
+
+        my $checksum_given = $values->{"_shelx_${type}_checksum"}[0];
+
+        if( $checksum_given !~ /^[0-9]+$/ ) {
+            push @messages, "NOTE, data item '_shelx_${type}_checksum' " .
+                            "has a non-numeric value '$checksum_given' " .
+                            "-- checksum of the '_shelx_${type}_file' " .
+                            'data item will not be verified';
+            next;
+        }
+
+        my $checksum_calc =
+            calculate_shelx_checksum( $values->{"_shelx_${type}_file"}[0] );
+        next if $checksum_given == $checksum_calc;
+        push @messages, 'NOTE, the provided and computed checksums of ' .
+                        "the '_shelx_${type}_file' SHELX data item do " .
+                        "not match ('$checksum_given' vs. '$checksum_calc')";
+    }
+
+    return \@messages;
+}
+
 # Check whether specified tags are all simultaneously present. This
 # check in COD is important for _atom_site_fractional_{x,y,z},
 # _atom_site_Cartesian_{x,y,z} and _atom_site_aniso_U_?? data items.
@@ -616,7 +663,7 @@ sub check_pdcif_relations
 
             $claimed_phases{$phase_nr} = 1;
             $claimed_diffractograms{$diffractogram_nr} = 1;
-            
+
             next if !exists $phase_data->{_pd_block_diffractogram_id};
 
             my $found = 0;
@@ -667,22 +714,51 @@ sub check_pdcif_relations
     return \@messages;
 }
 
-sub check_temperature_factors
+##
+# Checks if the data block contains atomic displacement parameters (ADP).
+# The check may optionally apply only to entries published after a certain
+# year (i.e. 1969).
+#
+# @param $dataset
+#       Reference to a data block as returned by the COD::CIF::Parser.
+# @param $options
+#       Reference to a hash of options. The following options are recognised:
+#       {
+#         # Only check and report entries that were published after
+#         # the given year. An undefined value means that all entries
+#         # should be checked regardless of the publication year.
+#           'mandatory_year_cutoff' => 1969,
+#       }
+# @return
+#       Reference to an array of audit messages.
+##
+sub check_adp_presence
 {
-    my($dataset, $options) = @_;
+    my ($dataset, $options) = @_;
     my @messages;
 
-    my $mandatory_year_cutoff = defined $options->{'mandatory_year_cutoff'} ?
-                                        $options->{'mandatory_year_cutoff'} :
-                                       '1969';
+    my $mandatory_year_cutoff = $options->{'mandatory_year_cutoff'};
 
-    my $values = $dataset->{values};
+    my $values = $dataset->{'values'};
 
-    if( tag_is_empty( $dataset, '_journal_year' ) ) {
-        return \@messages;
-    }
-    if( $values->{_journal_year}[0] <= $mandatory_year_cutoff ) {
-        return \@messages;
+    if( defined $mandatory_year_cutoff ) {
+        if( tag_is_empty( $dataset, '_journal_year' ) ) {
+            push @messages,
+                 'NOTE, could not check the mandatory presence of atomic ' .
+                 'displacement parameters -- data item \'_journal_year\' ' .
+                 'was not found';
+            return \@messages;
+        }
+        if( $values->{'_journal_year'}[0] !~ m/^[0-9]{4}$/ ) {
+            push @messages,
+                 'WARNING, could not check the mandatory presence of atomic ' .
+                 'displacement parameters -- data item \'_journal_year\' value ' .
+                 "'$values->{'_journal_year'}[0]' is not a 4 digit integer";
+            return \@messages;
+        }
+        if( $values->{'_journal_year'}[0] <= $mandatory_year_cutoff ) {
+            return \@messages;
+        }
     }
 
     if( !tag_is_empty($dataset,'_atom_site_B_iso_or_equiv') ||
@@ -697,13 +773,57 @@ sub check_temperature_factors
             return \@messages;
         }
     }
-    push @messages, 'WARNING, structure is published after '
-       . "$mandatory_year_cutoff, but does not contain "
-       . 'temperature factors';
+
+    if( defined $mandatory_year_cutoff ) {
+        push @messages,
+             "WARNING, structure is published after $mandatory_year_cutoff, " .
+             'but the atomic displacement parameters are not provided';
+    } else {
+        push @messages,
+             'WARNING, the atomic displacement parameters are not provided';
+    }
 
     return \@messages;
 }
 
+# TODO: remove the subroutine in the next major release.
+##
+# NOTE: this subroutine has been deprecated and was replaced by
+# the check_adp_presence() subroutine. The new subroutine allows
+# to check the ADP presence regardless of the year and does not
+# enforce a default 'mandatory_year_cutoff' option value.
+#
+# Checks if the data block that if published after a certain year contains
+# atomic displacement parameters (ADP).
+#
+# @param $dataset
+#       Reference to a data block as returned by the COD::CIF::Parser.
+# @param $options
+#       Reference to a hash of options. The following options are recognised:
+#       {
+#         # Only check and report entries that were published after
+#         # the given year. Default: 1969
+#           'mandatory_year_cutoff' => 1969,
+#       }
+# @return
+#       Reference to an array of audit messages.
+##
+sub check_temperature_factors
+{
+    my($dataset, $options) = @_;
+
+    my $mandatory_year_cutoff = defined $options->{'mandatory_year_cutoff'} ?
+                                        $options->{'mandatory_year_cutoff'} :
+                                        '1969';
+
+    my $warnings = check_adp_presence(
+                      $dataset,
+                      { 'mandatory_year_cutoff' => $mandatory_year_cutoff }
+                   );
+
+    return $warnings
+}
+
 ##
 # Checks if the data item values provided in the data block lie within the
 # expected limits. All checked non-numeric or *negative* values are reported
