@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $
-#$Revision: 8230 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
+#$Date: 2021-05-06 16:52:18 +0300 (Thu, 06 May 2021) $
+#$Revision: 8771 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
 #------------------------------------------------------------------------------
 #*
 #  Calculate unit cell contents from the atomic coordinates and
@@ -126,11 +126,11 @@ sub symop_generate_atoms($$@)
     $options = {} unless $options;
 
     my @sym_atoms;
-
     for my $atom ( @{$atoms} ) {
-        my( $sym_atoms ) = symops_apply_modulo1( $atom, $sym_operators,
+        my( $sym_atoms ) = symops_apply_modulo1( $atom,
+                                                 $sym_operators,
                                                  $options );
-        push( @sym_atoms, @$sym_atoms );
+        push @sym_atoms, @$sym_atoms;
     }
 
     return \@sym_atoms;
@@ -246,11 +246,32 @@ sub symop_register_applied_symop($$@)
     return $new_atom_info;
 }
 
-#===============================================================#
-# Generate symmetry equivalents of an atom, evaluate atom's
-# multiplicity and multiplicity ratio. Exclude atoms mapping to the
-# original one.
-
+##
+# Generates symmetry equivalents of an atom, evaluate atom's
+# multiplicity and multiplicity ratio.
+#
+# @param $atom
+#       Reference to an atom hash to generate symmetry equivalents for.
+# @param $sym_operators
+#       Reference to an array of symmetry operators.
+# @param $options
+#       Reference to a hash of options. The following options are recognised:
+#       {
+#       # Do not merge atoms in special positions
+#           'append_atoms_mapping_to_self'  => 1,
+#       # Passed to symop_apply()
+#           'append_symop_to_label'         => 0,
+#       # Generate symmetry equivalents to atoms marked as disordered
+#       # around special position
+#           'use_special_position_disorder' => 0,
+#       }
+# @return $sym_atoms
+#        Array of atom hashes representing generated atoms.
+# @return $multiplicity
+#        General position multiplicity divided by multiplicity ratio.
+# @return $multiplicity_ratio
+#        Multiplicity ratio.
+##
 sub symops_apply_modulo1($$@)
 {
     my ( $atom, $sym_operators, $options ) = @_;
@@ -332,6 +353,22 @@ sub symops_apply_modulo1($$@)
         ];
     }
 
+    # Exclude duplicates on special positions if requested
+    if( exists $options->{append_atoms_mapping_to_self} &&
+        !$options->{append_atoms_mapping_to_self} ) {
+        my %to_be_deleted;
+        for my $i (0..$#sym_atoms-1) {
+            for my $j ($i+1..$#sym_atoms) {
+                if( atoms_coincide( $sym_atoms[$i],
+                                    $sym_atoms[$j],
+                                    $sym_atoms[$i]->{f2o} )) {
+                    $to_be_deleted{ $sym_atoms[$j]->{name} } = 1;
+                }
+            }
+        }
+        @sym_atoms = grep { !$to_be_deleted{$_->{name}} } @sym_atoms;
+    }
+
     return ( \@sym_atoms, $multiplicity, $multiplicity_ratio );
 }
 
@@ -531,7 +568,7 @@ sub test_bump($$$$$$$@)
          $dist, $bump_factor, $radius_type ) = @_;
 
     $radius_type = "covalent_radius" if !defined $radius_type;
-    
+
     my $radius1 = $atom_properties->{$chemical_type1}->{$radius_type};
     my $radius2 = $atom_properties->{$chemical_type2}->{$radius_type};
 
