@@ -1,10 +1,10 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $ 
-#$Revision: 8230 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.0.1/src/lib/perl5/COD/CIF/Tags/Manage.pm $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Tags/Manage.pm $
 #------------------------------------------------------------------------
-#* 
+#*
 #  CIF tag management functions that work on the internal
 #  representation of a CIF file returned by the COD::CIF::Parser module.
 #**
@@ -96,7 +96,7 @@ sub tag_is_empty
             last;
         }
     }
-        
+
     return $is_empty;
 }
 
@@ -442,7 +442,7 @@ sub set_tag
     if ( !contains_data_item( $cif, $tag ) ) {
         push @{$cif->{tags}}, $tag;
     }
-    $cif->{values}{$tag}[0] = $value;
+    $cif->{values}{$tag} = [ $value ];
 
     return;
 }
