@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 17:58:23 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7411 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.8/src/lib/perl5/COD/UserMessage.pm $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/UserMessage.pm $
 #------------------------------------------------------------------------------
 #*
 #  Format run time error and warning messages in a uniform way.
@@ -41,16 +41,23 @@ my %add_pos_escape  = ( %common_escape );
 my %message_escape  = ( %common_escape );
 
 #==============================================================================
-# Print a message, reporting a program name, file name, data block
-# name and the error level (i.e., ERROR) in a uniform way.
+# Construct an error message, reporting a program name, file name, data block
+# name and the error level (i.e. ERROR) in a uniform way.
 
-sub sprint_message($$$$$$@)
+sub sprint_message
 {
-    my ( $program, $filename, $add_pos, $err_level, $message,
-         $explanation, $line, $column, $line_contents ) = @_;
+    my ( $message_details ) = @_;
+
+    my $program      = $message_details->{'program'};
+    my $filename     = $message_details->{'filename'};
+    my $line_no      = $message_details->{'line_no'};
+    my $column_no    = $message_details->{'column_no'};
+    my $add_pos      = $message_details->{'add_pos'};
+    my $err_level    = $message_details->{'err_level'};
+    my $message      = $message_details->{'message'};
+    my $line_content = $message_details->{'line_content'};
 
     $message =~ s/\.?\n?$//;
-    $explanation =~ s/\.?\n?$// if defined $explanation;
 
     #$program = "perl -e '...'" if ( $program eq '-e' );
 
@@ -58,49 +65,85 @@ sub sprint_message($$$$$$@)
     $filename    = escape_meta( $filename,    \%filename_escape );
     $add_pos     = escape_meta( $add_pos,     \%add_pos_escape  );
     $message     = escape_meta( $message,     \%message_escape  );
-    $explanation = escape_meta( $explanation, \%message_escape  );
 
-    $line_contents = prefix_multiline($line_contents);
+    $line_content = prefix_multiline($line_content);
 
     return $program . ':' .
            (defined $filename ? ' ' . $filename .
-                (defined $line ? "($line" .
-                    (defined $column ? ",$column" : '') . ')'
+                (defined $line_no ? "($line_no" .
+                    (defined $column_no ? ",$column_no" : '') . ')'
                 : '') .
                 (defined $add_pos ? " $add_pos" : '')
            : '') . ': ' .
            (defined $err_level ? $err_level . ', ' : '') .
            $message .
-           (defined $explanation ? ' -- ' . $explanation : '') .
-           (defined $line_contents ? ":\n" . $line_contents . "\n" .
-                (defined $column ? ' ' . ' ' x max( 0, $column-1 ) . "^\n" : '')
-                : ".\n");}
+           (defined $line_content ? ":\n" . $line_content . "\n" .
+                (defined $column_no ? ' ' . ' ' x max( 0, $column_no-1 ) . "^\n" : '')
+                : ".\n");
+}
 
 #==============================================================================
 # Generic function for printing messages to STDERR
 
-sub print_message($$$$$$@)
+sub print_message
 {
-    my ( $program, $filename, $add_pos, $err_level, $message,
-         $explanation, $line, $column, $line_contents ) = @_;
-    print STDERR sprint_message( $program, $filename, $add_pos, $err_level,
-                                 $message, $explanation, $line, $column,
-                                 $line_contents );
+    my ( $message_details ) = @_;
+    print STDERR sprint_message( $message_details );
+
+    return;
 }
 
-#==============================================================================
-# Parse an error message, generated by print_message. To be parsed
-# correctly, program, file and data block names as well as error level must
-# not not contain colons (':'). Error level is confined to uninterrupted
-# word without colons and commas (','). Error level can be separated from
-# the rest of the message by colon.
+###
+# Parses an error message based on the formal error message grammar [1].
+# Error messages that adhere to the aforementioned grammar can be produced
+# using the sprint_message() subroutine.
+#
+# @source [1]
+#       "EBNF grammar", supporting information of [2].
+#       doi: 10.1107/S1600576715022396/po5052sup2.txt
+# @source [2]
+#       Merkys, A., Vaitkus, A., Butkus, J., Okulič-Kazarinas, M.,
+#       Kairys, V. & Gražulis, S. (2016). COD::CIF::Parser:
+#       an error-correcting CIF parser for the Perl language.
+#       Journal of Applied Crystallography, 49.
+#       doi: 10.1107/S1600576715022396
+# @param $message
+#       Text string that contains the error message.
+# @return
+#       Reference to a hash that contains the parsed error message
+#       or an undef value if the message could not be parsed.
+#       The returned hash contains the following keys:
+#       {
+#         # Name of the program that issued the error
+#           'program'   => 'cif_parse',
+#         # Name of the file that caused the error
+#           'filename'  => 'test.cif',
+#         # Number of the line that caused the error
+#           'line_no'   => 13,
+#         # Number of the line column that caused the error
+#           'column_no' => 27,
+#         # Additional details about the location of the error
+#           'add_pos'   => 'data_parser_test_1',
+#         # Error level
+#           'err_level' => 'ERROR',
+#         # Message explaining the error
+#           'message'   => 'incorrect CIF syntax',
+#         # Lines that caused the error
+#           'line_content' => "loop__\n" .
+#                             "^\n"
+#       }
+#
+#       All keys except for 'program' and 'message' may have
+#       undef values.
+###
 sub parse_message($)
 {
     my( $message ) = @_;
 
-    my $program   = qr/[A-Za-z0-9_,-.\/&;# \t]+/;
-    my $file_name = qr/[A-Za-z0-9_,-.\/&;#]+/;
-    my $err_level = qr/[A-Z][A-Z_0-9 ]*/ms;
+    my $file_name_char = qr/[^\x{00}-\x{20}():\[\]\{\}\x{7F}]/;
+    my $program   = qr/$file_name_char(?:$file_name_char|[ \t])*/;
+    my $file_name = qr/$file_name_char+/;
+    my $err_level = qr/[A-Z][A-Z_0-9 -]*/ms;
     if( $message =~ /^
              ($program):[ ]?
              (?:
@@ -134,52 +177,80 @@ sub parse_message($)
 
 #==============================================================================
 # Report an error message. Errors are indicated with the "ERROR"
-# keyword in the message line. This is supposed to be a fatal even,
+# keyword in the message line. This is supposed to be a fatal event,
 # and the program will most probably die() or exit(255) after this
 # message, but the UserMessage package does not enforce this policy.
 
-sub error($$$$$)
+sub error
 {
-    my ( $program, $filename, $add_pos, $message, $explanation ) = @_;
-    print_message( $program, $filename, $add_pos,
-                   'ERROR', $message, $explanation );
+    my ( $message_details ) = @_;
+    print_message( {
+        'err_level' => 'ERROR',
+        'program'   => $message_details->{'program'},
+        'filename'  => $message_details->{'filename'},
+        'add_pos'   => $message_details->{'add_pos'},
+        'message'   => $message_details->{'message'}
+    } );
+
+    return;
 }
 
 #==============================================================================
 # Report a warning message. Warnings are indicated with the "WARNING"
 # keyword. Program can probably continue after warnings and give a
-# reasonable result, but it might be not the result which the user
+# reasonable result, but it might not be the result which the user
 # expected.
 
-sub warning($$$$$)
+sub warning
 {
-    my ( $program, $filename, $add_pos, $message, $explanation ) = @_;
-    print_message( $program, $filename, $add_pos,
-                   'WARNING', $message, $explanation );
+    my ( $message_details ) = @_;
+    print_message( {
+        'err_level' => 'WARNING',
+        'program'   => $message_details->{'program'},
+        'filename'  => $message_details->{'filename'},
+        'add_pos'   => $message_details->{'add_pos'},
+        'message'   => $message_details->{'message'}
+    } );
+
+    return;
 }
 
 #==============================================================================
 # Report a note message. Notes are indicated with the "NOTE"
 # keyword. Program can always continue after issuing notes as the intent
-# of note is just to provide information on the progress.
+# of note is to just provide information on the progress.
 
-sub note($$$$$)
+sub note
 {
-    my ( $program, $filename, $add_pos, $message, $explanation ) = @_;
-    print_message( $program, $filename, $add_pos,
-                   'NOTE', $message, $explanation );
+    my ( $message_details ) = @_;
+    print_message( {
+        'err_level' => 'NOTE',
+        'program'   => $message_details->{'program'},
+        'filename'  => $message_details->{'filename'},
+        'add_pos'   => $message_details->{'add_pos'},
+        'message'   => $message_details->{'message'}
+    } );
+
+    return;
 }
 
 #==============================================================================
 # Report a debug message. Notes are indicated with the "DEBUG"
-# keyword. Debug messages should only be printed uppon user request to output
+# keyword. Debug messages should only be printed upon user request to output
 # additional information.
 
-sub debug_note($$$$$)
+sub debug_note
 {
-    my ( $program, $filename, $add_pos, $message, $explanation ) = @_;
-    print_message( $program, $filename, $add_pos,
-                   'DEBUG', $message, $explanation );
+    my ( $message_details ) = @_;
+    print_message( {
+        'err_level' => 'DEBUG',
+        'program'   => $message_details->{'program'},
+        'filename'  => $message_details->{'filename'},
+        'add_pos'   => $message_details->{'add_pos'},
+        'message'   => $message_details->{'message'}
+    } );
+
+    return;
 }
 
 sub escape_meta {
