@@ -1,10 +1,10 @@
 #------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2020-09-07 17:57:43 +0300 (Mon, 07 Sep 2020) $ 
-#$Revision: 8469 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/src/lib/perl5/COD/CIF/Tags/Print.pm $
+#$Author: antanas $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/CIF/Tags/Print.pm $
 #------------------------------------------------------------------------
-#* 
+#*
 #  CIF tag management functions that work on the internal representation
 #  of a CIF file as returned by the COD::CIF::Parser module.
 #**
@@ -212,6 +212,7 @@ sub print_loop
 {
     my ( $data_block, $loop_nr, $options ) = @_;
 
+    $options = {} unless $options;
     my $values = $data_block->{'values'};
     my @loop_tags = @{$data_block->{loops}[$loop_nr]};
 
