@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-11-15 18:13:46 +0200 (Fri, 15 Nov 2019) $ 
-#$Revision: 7412 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.0.1/src/lib/perl5/COD/Precision.pm $
+#$Date: 2021-04-28 17:11:36 +0300 (Wed, 28 Apr 2021) $
+#$Revision: 8737 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/src/lib/perl5/COD/Precision.pm $
 #------------------------------------------------------------------------
 
 package COD::Precision;
@@ -22,6 +22,9 @@ our @EXPORT_OK = qw(
 sub unpack_precision
 {
     my( $value, $precision ) = @_;
+
+    return $precision if $precision =~ /\./;
+
     # - $1 - part before decimal dot
     # - $2 - decimal dot
     # - $3 - mantissa (part after d-dot)
@@ -47,7 +50,7 @@ sub unpack_cif_number
 {
     my( $number ) = @_;
     my $sigma;
-    if( $number =~ s/\(([0-9]+)\)$// ) {
+    if( $number =~ s/\(([0-9\.]+)\)$// ) {
         $sigma = $1;
     }
     my $precision;
