@@ -6,12 +6,12 @@ INPUT_DDL_MODULE='src/lib/perl5/COD/CIF/DDL.pm'
 INPUT_CIF='tests/inputs/4308312-audit-dict-name.cif'
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+TEST_SCRIPT=$(cat <<'END_SCRIPT'
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2020-07-10 15:53:55 +0300 (Fri, 10 Jul 2020) $ 
-#$Revision: 8185 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/tests/shtests/get_cif_dictionary_ids_001.sh $
+#$Date: 2020-11-08 07:33:15 +0200 (Sun, 08 Nov 2020) $ 
+#$Revision: 8571 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/tests/shtests/get_cif_dictionary_ids_001.sh $
 #------------------------------------------------------------------------------
 #*
 #* Unit test for the COD::CIF::DDL::get_cif_dictionary_ids() subroutine.
@@ -26,11 +26,16 @@ use Data::Dumper;
 
 $Data::Dumper::Sortkeys = 1;
 
+my $filename = $ARGV[0];
+
 my( $data, $dataset );
 
-( $data ) = parse_cif( 'tests/inputs/4308312-audit-dict-name.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 print Dumper get_cif_dictionary_ids( $dataset );
 
 END_SCRIPT
+)
+
+perl -e "${TEST_SCRIPT}" "${INPUT_CIF}"
