@@ -3,15 +3,15 @@
 #BEGIN DEPEND------------------------------------------------------------------
 INPUT_PARSER='src/lib/perl5/COD/CIF/Parser.pm'
 INPUT_NEIGHBOURS_MODULE='src/lib/perl5/COD/AtomNeighbours.pm'
-INPUT_CIF='tests/inputs/2006199.cif'
+INPUT_CIF='tests/inputs/lib/COD/AtomNeighbours/neighbour_list_from_cif/2006199.cif'
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+TEST_SCRIPT=$(cat <<'END_SCRIPT'
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2020-07-29 16:47:24 +0300 (Wed, 29 Jul 2020) $ 
-#$Revision: 8257 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/tests/shtests/neighbour_list_from_cif_003.sh $
+#$Author: antanas $
+#$Date: 2020-11-08 07:33:15 +0200 (Sun, 08 Nov 2020) $ 
+#$Revision: 8571 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/tests/shtests/neighbour_list_from_cif_003.sh $
 #------------------------------------------------------------------------------
 #*
 #* Unit test for the COD::AtomNeighbours::neighbour_list_from_cif() subroutine.
@@ -26,12 +26,17 @@ use Data::Dumper;
 
 $Data::Dumper::Sortkeys = 1;
 
+my $filename = $ARGV[0];
+
 my( $data, $dataset );
 
-( $data ) = parse_cif( 'tests/inputs/2006199.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 my $neighbour_list = neighbour_list_from_cif( $dataset );
 print Dumper $neighbour_list->{neighbours};
 
 END_SCRIPT
+)
+
+perl -e "${TEST_SCRIPT}" "${INPUT_CIF}"
