@@ -6,12 +6,12 @@ INPUT_NEIGHBOURS_MODULE='src/lib/perl5/COD/AtomNeighbours.pm'
 INPUT_CIF='tests/inputs/1000049.cif'
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+TEST_SCRIPT=$(cat <<'END_SCRIPT'
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2020-07-30 14:56:44 +0300 (Thu, 30 Jul 2020) $ 
-#$Revision: 8259 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/tests/shtests/neighbour_list_from_cif_004.sh $
+#$Author: antanas $
+#$Date: 2020-11-08 07:33:15 +0200 (Sun, 08 Nov 2020) $ 
+#$Revision: 8571 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/tests/shtests/neighbour_list_from_cif_004.sh $
 #------------------------------------------------------------------------------
 #*
 #* Unit test for the COD::AtomNeighbours::neighbour_list_from_cif() subroutine.
@@ -26,12 +26,17 @@ use Data::Dumper;
 
 $Data::Dumper::Sortkeys = 1;
 
+my $filename = $ARGV[0];
+
 my( $data, $dataset );
 
-( $data ) = parse_cif( 'tests/inputs/1000049.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 my $neighbour_list = neighbour_list_from_cif( $dataset );
 print Dumper $neighbour_list->{atoms};
 
 END_SCRIPT
+)
+
+perl -e "${TEST_SCRIPT}" "${INPUT_CIF}"
