@@ -6,12 +6,12 @@ INPUT_TAG_MANAGE='src/lib/perl5/COD/CIF/Tags/Manage.pm'
 INPUT_CIF='tests/inputs/generic.cif'
 #END DEPEND--------------------------------------------------------------------
 
-perl <<'END_SCRIPT'
+TEST_SCRIPT=$(cat <<'END_SCRIPT'
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2018-09-04 09:46:03 +0300 (Tue, 04 Sep 2018) $ 
-#$Revision: 6407 $
-#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.1.0/tests/shtests/rename_tag_001.sh $
+#$Author: antanas $
+#$Date: 2020-11-08 07:33:15 +0200 (Sun, 08 Nov 2020) $ 
+#$Revision: 8571 $
+#$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.2.0/tests/shtests/rename_tag_001.sh $
 #------------------------------------------------------------------------------
 #*
 #* Unit test for the COD::CIF::Tags::Manage::rename_tag() subroutine.
@@ -27,9 +27,11 @@ use Text::Diff;
 
 $Data::Dumper::Sortkeys = 1;
 
+my $filename = $ARGV[0];
+
 my( $data, $dataset );
 
-( $data ) = parse_cif( 'tests/inputs/generic.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 my $full_struct = Dumper $dataset;
@@ -41,14 +43,14 @@ print "Renaming '_tag3' to '_renamed_tag3':\n";
 rename_tag( $dataset, '_tag3', '_renamed_tag3' );
 print diff( \$full_struct, \(Dumper $dataset) ) || "(no difference)\n";
 
-( $data ) = parse_cif( 'tests/inputs/generic.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 print "Renaming '_tag1' to '_tag1':\n";
 rename_tag( $dataset, '_tag1', '_tag1' );
 print diff( \$full_struct, \(Dumper $dataset) ) || "(no difference)\n";
 
-( $data ) = parse_cif( 'tests/inputs/generic.cif' );
+( $data ) = parse_cif( $filename );
 ( $dataset ) = @$data;
 
 print "Renaming '_tag1' to '_tag2':\n";
@@ -56,3 +58,6 @@ rename_tag( $dataset, '_tag1', '_tag2' );
 print diff( \$full_struct, \(Dumper $dataset) ) || "(no difference)\n";
 
 END_SCRIPT
+)
+
+perl -e "${TEST_SCRIPT}" "${INPUT_CIF}"
